"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createExperimentModel = exports.createServiceConfigurationModel = exports.createParticipantModel = exports.createPeerconnectionModel = exports.createRoleModel = exports.createDeviceModel = void 0;
const repositories_1 = require("../repositories");
const write_1 = require("./write");
/**
 * This function attempts to create a device model with the device provided.
 * @param device The device providing the data for the model.
 * @returns The created device model.
 */
function createDeviceModel(device) {
    const deviceModel = repositories_1.deviceRepository.create();
    (0, write_1.writeDeviceModel)(deviceModel, device);
    return deviceModel;
}
exports.createDeviceModel = createDeviceModel;
/**
 * This function attempts to create a role model with the role provided.
 * @param role The role providing the data for the model.
 * @returns The created role model.
 */
function createRoleModel(role) {
    const roleModel = repositories_1.roleRepository.create();
    (0, write_1.writeRoleModel)(roleModel, role);
    return roleModel;
}
exports.createRoleModel = createRoleModel;
/**
 * This function attempts to create a peerconnection model with the peerconnection url provided.
 * @param peerconnectionUrl The url of the peerconnection.
 * @returns The created peerconnection model.
 */
function createPeerconnectionModel(peerconnectionUrl) {
    const peerconnectionModel = repositories_1.peerconnectionRepository.create();
    (0, write_1.writePeerconnectionModel)(peerconnectionModel, peerconnectionUrl);
    return peerconnectionModel;
}
exports.createPeerconnectionModel = createPeerconnectionModel;
/**
 * This function attempts to create a participant model with the participant provided.
 * @param participant The participant providing the data for the model.
 * @returns The created participant model.
 */
function createParticipantModel(participant) {
    const participantModel = repositories_1.participantRepository.create();
    (0, write_1.writeParticipantModel)(participantModel, participant);
    return participantModel;
}
exports.createParticipantModel = createParticipantModel;
/**
 * This function attempts to create a service configuration model with the service configuration provided.
 * @param serviceConfiguration The service configuration providing the data for the model.
 * @returns The created service configuration model.
 */
function createServiceConfigurationModel(serviceConfiguration) {
    const serviceConfigurationModel = repositories_1.serviceConfigurationRepository.create();
    (0, write_1.writeServiceConfigurationModel)(serviceConfigurationModel, serviceConfiguration);
    return serviceConfigurationModel;
}
exports.createServiceConfigurationModel = createServiceConfigurationModel;
/**
 * This function attempts to create an experiment model with the data provided.
 * The status of the newly created experiment model will always be "created".
 * @param experiment The experiment providing the data for the model.
 * @returns The created experiment model.
 */
function createExperimentModel(experiment) {
    const experimentModel = repositories_1.experimentRepository.create();
    (0, write_1.writeExperimentModel)(experimentModel, experiment);
    experimentModel.status = 'created';
    return experimentModel;
}
exports.createExperimentModel = createExperimentModel;
//# sourceMappingURL=create.js.map