"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findPeerconnectionModelByUrl = exports.findExperimentModelById = exports.findAllExperimentModels = void 0;
const repositories_1 = require("../repositories");
/**
 * This function returns all experiment models found in the database.
 * @returns All experiment models found in the database.
 */
async function findAllExperimentModels() {
    return await repositories_1.experimentRepository.find();
}
exports.findAllExperimentModels = findAllExperimentModels;
/**
 * This function attempts to find a specific experiment model by its id.
 * @param experimentModelId The id of the experiment model.
 * @returns The found experiment model.
 */
async function findExperimentModelById(experimentModelId) {
    return await repositories_1.experimentRepository.findOne({
        where: {
            uuid: experimentModelId,
        },
        relations: {
            devices: true,
            connections: true,
            roles: true,
            serviceConfigurations: true,
        },
    });
}
exports.findExperimentModelById = findExperimentModelById;
/**
 * This function attempts to find a specific peerconnection model by its url.
 * @param peerconnectionUrl The url of the peerconnection model.
 * @returns The found peerconnection model.
 */
async function findPeerconnectionModelByUrl(peerconnectionUrl) {
    return await repositories_1.peerconnectionRepository.findOne({
        where: {
            url: peerconnectionUrl,
        },
        relations: {
            experiment: {
                connections: true,
            },
        },
    });
}
exports.findPeerconnectionModelByUrl = findPeerconnectionModelByUrl;
//# sourceMappingURL=find.js.map