#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
const data_source_1 = require("./database/data_source");
const index_1 = require("./generated/index");
const api_1 = require("./util/api");
const callbacks_1 = require("./util/callbacks");
const logger_1 = require("./util/logger");
const service_common_1 = require("@crosslab/service-common");
const express_winston_1 = __importDefault(require("express-winston"));
data_source_1.AppDataSource.initialize()
    .then(() => {
    api_1.apiClient.accessToken = config_1.config.API_TOKEN;
    index_1.app.use(express_winston_1.default.logger({
        winstonInstance: logger_1.logger,
        // optional: control whether you want to log the meta data about the request (default to true)
        meta: true,
        // optional: customize the default logging message. E.g. "{{res.statusCode}} {{req.method}} {{res.responseTime}}ms {{req.url}}"
        msg: 'HTTP {{res.statusCode}} {{req.method}} {{res.responseTime}}ms {{req.url}}',
        // Use the default Express/morgan request formatting. Enabling this will override any msg if true.
        // Will only output colors with colorize set to true
        expressFormat: true,
        // Color the text and status code, using the Express/morgan color palette
        // (text: gray, status: default green, 3XX cyan, 4XX yellow, 5XX red).
        colorize: false,
        // optional: allows to skip some log messages based on request and/or response
        ignoreRoute: function (_req, _res) {
            return false;
        },
        requestFilter: (req, propName) => {
            if (propName === 'headers' && req.headers.authorization)
                return {
                    ...req.headers,
                    authorization: 'HIDDEN',
                };
            return req[propName];
        },
    }));
    index_1.app.get('/experiment/status', (_req, res) => {
        res.send({ status: 'ok' });
    });
    index_1.app.initService({
        security: {
            JWT: (0, service_common_1.JWTVerify)(config_1.config),
        },
        additionalHandlers: [callbacks_1.callbackHandling],
    });
    index_1.app.listen(config_1.config.PORT);
})
    .catch((err) => {
    console.error('Error during Data Source initialization:', err);
});
//# sourceMappingURL=index.js.map