"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MalformedBodyError = exports.JWTVerificationError = exports.InvalidBookingError = exports.InternalRequestError = exports.DeviceNotConnectedError = exports.MissingPropertyError = exports.InconsistentDatabaseError = exports.InvalidStateError = exports.ServiceConfigurationError = exports.InvalidValueError = exports.MissingEntityError = void 0;
const types_1 = require("../generated/types");
/**
 * This error class should be used if an entity is not found in the database.
 */
class MissingEntityError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'MissingEntityError';
    }
}
exports.MissingEntityError = MissingEntityError;
/**
 * This error class should be used if an object contains an invalid value.
 */
class InvalidValueError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InvalidValueError';
    }
}
exports.InvalidValueError = InvalidValueError;
/**
 * This error class should be used if a service configuration is faulty.
 */
class ServiceConfigurationError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'ServiceConfigurationError';
    }
}
exports.ServiceConfigurationError = ServiceConfigurationError;
/**
 * This error class should be used if an operation cannot be executed from the current state.
 */
class InvalidStateError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InvalidStateError';
    }
}
exports.InvalidStateError = InvalidStateError;
/**
 * This error class should be used if there is an inconsistency in the database.
 */
class InconsistentDatabaseError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InconsistentDatabaseError';
    }
}
exports.InconsistentDatabaseError = InconsistentDatabaseError;
/**
 * This error class should be used if an object is missing a needed property.
 */
class MissingPropertyError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'MissingPropertyError';
    }
}
exports.MissingPropertyError = MissingPropertyError;
/**
 * This error class should be used if a required device is not connection.
 */
class DeviceNotConnectedError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'DeviceNotConnectedError';
    }
}
exports.DeviceNotConnectedError = DeviceNotConnectedError;
/**
 * This error class should be used as a wrapper for errors thrown by the api-client.
 */
class InternalRequestError extends types_1.ErrorWithStatus {
    constructor(message, error, status) {
        super(message, status);
        this.name = 'InternalRequestError';
        this.internalError = error;
    }
}
exports.InternalRequestError = InternalRequestError;
/**
 * This error class should be used if a booking is invalid.
 */
class InvalidBookingError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = 'InvalidBookingError';
    }
}
exports.InvalidBookingError = InvalidBookingError;
/**
 * This error class should be used if an error occurs during JWT verification.
 */
class JWTVerificationError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = "JWTVerificationError";
    }
}
exports.JWTVerificationError = JWTVerificationError;
/**
 * This error class should be used if the body of a request is malformed.
 */
class MalformedBodyError extends types_1.ErrorWithStatus {
    constructor(message, status) {
        super(message, status);
        this.name = "MalformedBodyError";
    }
}
exports.MalformedBodyError = MalformedBodyError;
//# sourceMappingURL=errors.js.map