"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUrlOrInstanceUrl = exports.experimentUrlFromId = void 0;
const config_1 = require("../config");
/**
 * This function builds the url of an experiment using its id.
 * @param experimentId The id of the experiment.
 * @returns The url of the experiment.
 */
function experimentUrlFromId(experimentId) {
    return (config_1.config.BASE_URL +
        (config_1.config.BASE_URL.endsWith('/') ? '' : '/') +
        'experiments/' +
        experimentId);
}
exports.experimentUrlFromId = experimentUrlFromId;
/**
 * This function returns the instance url of a device if defined,
 * otherwise it returns the url of the device.
 * @param deviceModel The device of which to get the url.
 * @returns The instance url or the url of the device.
 */
function getUrlOrInstanceUrl(deviceModel) {
    if (deviceModel.additionalProperties &&
        deviceModel.additionalProperties.instanceUrl) {
        return deviceModel.additionalProperties.instanceUrl;
    }
    else {
        return deviceModel.url;
    }
}
exports.getUrlOrInstanceUrl = getUrlOrInstanceUrl;
//# sourceMappingURL=url.js.map